#error "/home/harald/tmp/qt-3.3.7-harald-4508/qt/extensions/nsplugin/src/npwin.cpp must be provided by Netscape"
#error "This file is just a placeholder. Please see the documentation"
#error "to learn how to obtain the real file"
